@@ -3,7 +3,7 @@ package Mail::MtPolicyd::Plugin;
 use Moose;
 use namespace::autoclean;
 
-our $VERSION = '1.14'; # VERSION
+our $VERSION = '1.16'; # VERSION
 # ABSTRACT: a base class for plugins
 
 
@@ -29,21 +29,31 @@ sub log {
 	return;
 }
 
+sub init {
+    return;
+}
+
+sub cron {
+    return;
+}
+
 __PACKAGE__->meta->make_immutable;
 
 1;
 
-
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Mail::MtPolicyd::Plugin - a base class for plugins
 
 =head1 VERSION
 
-version 1.14
+version 1.16
 
 =head1 ATTRIBUTES
 
@@ -81,4 +91,3 @@ This is free software, licensed under:
   The GNU General Public License, Version 2, June 1991
 
 =cut
-
