@@ -2,7 +2,7 @@ package Mail::MtPolicyd::Plugin::Role::PluginChain;
 
 use Moose::Role;
 
-our $VERSION = '1.14'; # VERSION
+our $VERSION = '1.16'; # VERSION
 # ABSTRACT: role for plugins to support a nested plugin chain
 
 use Mail::MtPolicyd::PluginChain;
@@ -22,21 +22,32 @@ has 'chain' => (
 		return;
 	},
 );
+
 has 'Plugin' => ( is => 'rw', isa => 'Maybe[HashRef]' );
 
+after 'cron' => sub {
+    my $self = shift;
+    if( defined $self->chain ) {
+        return $self->chain->cron(@_);
+    }
+    return;
+};
+
 1;
 
-
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Mail::MtPolicyd::Plugin::Role::PluginChain - role for plugins to support a nested plugin chain
 
 =head1 VERSION
 
-version 1.14
+version 1.16
 
 =head1 AUTHOR
 
@@ -51,4 +62,3 @@ This is free software, licensed under:
   The GNU General Public License, Version 2, June 1991
 
 =cut
-
