@@ -3,7 +3,7 @@ package Mail::MtPolicyd::Plugin::SqlUserConfig;
 use Moose;
 use namespace::autoclean;
 
-our $VERSION = '1.15'; # VERSION
+our $VERSION = '1.16'; # VERSION
 # ABSTRACT: mtpolicyd plugin for retrieving the user config of a user
 
 extends 'Mail::MtPolicyd::Plugin';
@@ -25,14 +25,19 @@ has '_json' => (
 	}
 );
 
+has 'field' => ( is => 'rw', isa => 'Str', default => 'recipient' );
+
 sub _get_config {
 	my ( $self, $r ) = @_;
-	my $rcpt = $r->attr('recipient');
+	my $key = $r->attr( $self->field );
+    if( ! defined $key || $key =~ /^\s*$/ ) {
+        die('key field '.$self->field.' not defined or empty in request');
+    }
 
-	my $sth = $self->execute_sql( $self->sql_query, $rcpt );
+	my $sth = $self->execute_sql( $self->sql_query, $key );
 	my ( $json ) = $sth->fetchrow_array;
 	if( ! defined $json ) {
-		die( 'no user-config found for '.$rcpt );
+		die( 'no user-config found for '.$key );
 	}
 	return $self->_json->decode( $json );
 }
@@ -41,11 +46,6 @@ sub run {
 	my ( $self, $r ) = @_;
 	my $config;
 
-	if( ! defined $r->attr('recipient') ) {
-		$self->log($r, 'no attribute \'recipient\' in request');
-		return;
-	}
-
 	eval { $config = $self->_get_config($r) };
 	if( $@ ) {
 		$self->log($r, 'unable to retrieve user-config: '.$@);
@@ -76,7 +76,7 @@ Mail::MtPolicyd::Plugin::SqlUserConfig - mtpolicyd plugin for retrieving the use
 
 =head1 VERSION
 
-version 1.15
+version 1.16
 
 =head1 DESCRIPTION
 
@@ -95,6 +95,10 @@ The SQL query to retrieve the JSON configuration string.
 
 The content of the first row/column is used.
 
+=item field (default: recipient)
+
+The request field used in the sql query to retrieve the user configuration.
+
 =back
 
 =head1 EXAMPLE USER SPECIFIC GREYLISTING
