@@ -5,7 +5,7 @@ use namespace::autoclean;
 
 use Mail::MtPolicyd::Plugin::Result;
 
-our $VERSION = '1.13'; # VERSION
+our $VERSION = '1.16'; # VERSION
 # ABSTRACT: the request object
 
 
@@ -110,21 +110,39 @@ sub is_already_done {
 	return 0;
 }
 
+
+sub is_attr_defined {
+    my ( $self, @fields ) = @_;
+    my $a = $self->attributes;
+
+    foreach my $field ( @fields ) {
+        if( ! defined $a->{$field}
+                || $a->{$field} eq ''
+                || $a->{$field} =~ /^\s+$/ ) {
+            return 0;
+        }
+    }
+
+    return 1;
+}
+
 __PACKAGE__->meta->make_immutable;
 
 1;
 
-
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Mail::MtPolicyd::Request - the request object
 
 =head1 VERSION
 
-version 1.13
+version 1.16
 
 =head1 ATTRIBUTES
 
@@ -214,6 +232,10 @@ Example:
     $self->add_score($r, $self->name => $self->score);
   }
 
+=head2 is_attr_defined
+
+Returns true if all given attribute names are defined and non-empty.
+
 =head1 AUTHOR
 
 Markus Benning <ich@markusbenning.de>
@@ -227,4 +249,3 @@ This is free software, licensed under:
   The GNU General Public License, Version 2, June 1991
 
 =cut
-
